==> core-react-0.8.0.tgz: package/es/Button/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Icon from '../Icon';


function Button(props) {
  var _cx;

  var children = props.children,
      className = props.className,
      type = props.type,
      loading = props.loading,
      size = props.size,
      block = props.block,
      ghost = props.ghost,
      icon = props.icon,
      disabled = props.disabled,
      other = _objectWithoutProperties(props, ["children", "className", "type", "loading", "size", "block", "ghost", "icon", "disabled"]);

  var classNames = cx("".concat("waui", "-button"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-button--").concat(type), type), _defineProperty(_cx, "".concat("waui", "-button--").concat(size), size), _defineProperty(_cx, "".concat("waui", "-button--ghost"), ghost), _defineProperty(_cx, "".concat("waui", "-button--loading"), loading), _defineProperty(_cx, "".concat("waui", "-button--block"), block), _defineProperty(_cx, "".concat("waui", "-button__icon-only"), icon && !children), _cx), className);

  if (icon && children) {
    return React.createElement("button", _extends({
      type: "button",
      className: classNames,
      disabled: disabled || loading
    }, other), React.createElement("div", null, React.createElement(Icon, {
      type: icon
    }), React.createElement("span", null, children)));
  }

  return React.createElement("button", _extends({
    type: "button",
    className: classNames,
    disabled: disabled || loading
  }, other), icon && React.createElement(Icon, {
    type: icon
  }), children && React.createElement("span", null, children));
}

Button.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** button type */
  type: PropTypes.oneOf(['primary', 'accept', 'warning', 'danger', 'link', 'text']),

  /** button size */
  size: PropTypes.oneOf(['sm', 'md', 'lg']),

  /** determine whether it's a ghost button */
  ghost: PropTypes.bool,

  /** determine whether it's a block button */
  block: PropTypes.bool,

  /** determine whether it's loading */
  loading: PropTypes.bool,

  /** disable the button */
  disabled: PropTypes.bool,

  /** icon type name */
  icon: PropTypes.string
};
Button.defaultProps = {
  size: 'md'
};
export default Button;

==> core-react-0.8.2.tgz: package/es/Button/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Icon from '../Icon';


function Button(props) {
  var _cx;

  var children = props.children,
      className = props.className,
      type = props.type,
      loading = props.loading,
      size = props.size,
      block = props.block,
      ghost = props.ghost,
      icon = props.icon,
      disabled = props.disabled,
      other = _objectWithoutProperties(props, ["children", "className", "type", "loading", "size", "block", "ghost", "icon", "disabled"]);

  var classNames = cx("".concat("waui", "-button"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-button--").concat(type), type), _defineProperty(_cx, "".concat("waui", "-button--").concat(size), size), _defineProperty(_cx, "".concat("waui", "-button--ghost"), ghost), _defineProperty(_cx, "".concat("waui", "-button--loading"), loading), _defineProperty(_cx, "".concat("waui", "-button--block"), block), _defineProperty(_cx, "".concat("waui", "-button__icon-only"), icon && !children), _cx), className);

  if (icon && children) {
    return (/*#__PURE__*/React.createElement("button", _extends({
        type: "button",
        className: classNames,
        disabled: disabled || loading
      }, other), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Icon, {
        type: icon
      }), /*#__PURE__*/React.createElement("span", null, children)))
    );
  }

  return (/*#__PURE__*/React.createElement("button", _extends({
      type: "button",
      className: classNames,
      disabled: disabled || loading
    }, other), icon && /*#__PURE__*/React.createElement(Icon, {
      type: icon
    }), children && /*#__PURE__*/React.createElement("span", null, children))
  );
}

Button.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** button type */
  type: PropTypes.oneOf(['primary', 'accept', 'warning', 'danger', 'link', 'text']),

  /** button size */
  size: PropTypes.oneOf(['sm', 'md', 'lg']),

  /** determine whether it's a ghost button */
  ghost: PropTypes.bool,

  /** determine whether it's a block button */
  block: PropTypes.bool,

  /** determine whether it's loading */
  loading: PropTypes.bool,

  /** disable the button */
  disabled: PropTypes.bool,

  /** icon type name */
  icon: PropTypes.string
};
Button.defaultProps = {
  size: 'md'
};
export default Button;
